from osgeo import gdal


def open_gdal_dataset(input_file):
    return gdal.Open(input_file)


def write_gdal_dataset(src_dst, driver_name, output_file_name, creation_options):
    # writes dataset to an output file using a given driver and array of creation options (-CO)
    driver_instance = gdal.GetDriverByName(driver_name)
    dst_ds = driver_instance.CreateCopy(output_file_name, src_dst, strict=0, options=creation_options)
    # write to disk
    dst_ds = None


def correct_geo_transform(src_dst):
    # input - gdal dataset
    # sets new geotransform if necessary by creating control points of a raster with switched height and width - by Petr
    # returns - gdal dataset
    ulx, xres, xskew, uly, yskew, yres = src_dst.GetGeoTransform()
    # test geotransform if necessary to shift
    if xres == 0.0 and yres == 0.0:
        # malformed image, compute xres and yres switched in geotransform
        lrx = ulx + (src_dst.RasterXSize * xskew)
        lry = uly + (src_dst.RasterYSize * yskew)
        # [ulx, lrx, lry, uly] - bounds = lon_min, lon_max, lat_min, lat_max
        fp = [[0, src_dst.RasterXSize, src_dst.RasterXSize, 0], [0, 0, src_dst.RasterYSize, src_dst.RasterYSize]]
        tp = [[ulx, lrx, lrx, ulx], [lry, lry, uly, uly]]
        pix = list(zip(fp[0], fp[1]))
        coor = list(zip(tp[0], tp[1]))
        # compute the gdal.GCP parameters
        gcps = []
        for index, txt in enumerate(pix):
            gcps.append(gdal.GCP())
            gcps[index].GCPPixel = pix[index][0]
            gcps[index].GCPLine = src_dst.RasterYSize - int(pix[index][1])
            gcps[index].GCPX = coor[index][0]
            gcps[index].GCPY = coor[index][1]
        # get correct geotransform from gcps
        geotransform_new = gdal.GCPsToGeoTransform(gcps)
        # overwrite geotransform with new
        src_dst.SetGeoTransform(geotransform_new)
    return src_dst
